# ADR
[![Build Status](https://travis-ci.com/CeuAzul/ADR.svg?branch=master)](https://travis-ci.com/CeuAzul/ADR)
[![Coverage Status](https://coveralls.io/repos/github/CeuAzul/ADR/badge.svg)](https://coveralls.io/github/CeuAzul/ADR)


Aircraft Design Resources aims to help engineers on conceptual design analysis, giving them the tools necessary to easily simulate different aircraft designs.

## Installation
### Regular usage
```
git clone https://github.com/CeuAzul/ADR.git
cd ADR
pip install setuptools
pip install ./
```

### Development
```
git clone https://github.com/CeuAzul/ADR.git
cd ADR
pip install setuptools
pip install -e ./
```

## Usage

To run an analysis modify the inputs on *parameters.py* as needed and run *main.py*.

### Contributors

This project exists thanks to all the people who contribute.

[![Contributors](https://contributors-img.web.app/image?repo=CeuAzul/ADR)](https://github.com/CeuAzul/ADR/graphs/contributors)
